==> haskell-atomic-primops-0.8.8-74.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-atomic-primops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 atomic-primops
version:              0.8.8
visibility:           public
id:                   atomic-primops-0.8.8-BqFUQoFZVJ6CGcxPYpNQEr
key:                  atomic-primops-0.8.8-BqFUQoFZVJ6CGcxPYpNQEr
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             A safe approach to CAS and other atomic ops in Haskell.
description:
     After GHC 7.4 a new `casMutVar#` primop became available, but it'\''s
     difficult to use safely, because pointer equality is a highly
     unstable property in Haskell.  This library provides a safer method
     based on the concept of "Tickets".
    .
     Also, this library uses the "foreign primop" capability of GHC to
     add access to other variants that may be of
     interest, specifically, compare and swap inside an array.
    .
     Note that as of GHC 7.8, the relevant primops have been included in GHC itself.
     This library is engineered to work pre- and post-GHC-7.8, while exposing the
     same interface.

category:             Data
abi:                  50c0a7c29c427bc0bbb260015ef8b595
exposed:              True
exposed-modules:
    Data.Atomics Data.Atomics.Counter Data.Atomics.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/atomic-primops-0.8.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/atomic-primops-0.8.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/atomic-primops-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-atomic-primops
hs-libraries:         HSatomic-primops-0.8.8-BqFUQoFZVJ6CGcxPYpNQEr
depends:
    base-4.18.2.1 ghc-prim-0.10.0
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ

haddock-interfaces:
    /usr/share/doc/haskell-atomic-primops/html/atomic-primops.haddock

haddock-html:         /usr/share/doc/haskell-atomic-primops/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-atomic-primops-0.8.8-75-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-atomic-primops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 atomic-primops
version:              0.8.8
visibility:           public
id:                   atomic-primops-0.8.8-9HCVSnkeP1XAjM0zSbjqbR
key:                  atomic-primops-0.8.8-9HCVSnkeP1XAjM0zSbjqbR
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             A safe approach to CAS and other atomic ops in Haskell.
description:
     After GHC 7.4 a new `casMutVar#` primop became available, but it'\''s
     difficult to use safely, because pointer equality is a highly
     unstable property in Haskell.  This library provides a safer method
     based on the concept of "Tickets".
    .
     Also, this library uses the "foreign primop" capability of GHC to
     add access to other variants that may be of
     interest, specifically, compare and swap inside an array.
    .
     Note that as of GHC 7.8, the relevant primops have been included in GHC itself.
     This library is engineered to work pre- and post-GHC-7.8, while exposing the
     same interface.

category:             Data
abi:                  1b4e196100ef6d4413ec4b7da2fbb357
exposed:              True
exposed-modules:
    Data.Atomics Data.Atomics.Counter Data.Atomics.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/atomic-primops-0.8.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/atomic-primops-0.8.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/atomic-primops-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-atomic-primops
hs-libraries:         HSatomic-primops-0.8.8-9HCVSnkeP1XAjM0zSbjqbR
depends:
    base-4.18.2.1 ghc-prim-0.10.0
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi

haddock-interfaces:
    /usr/share/doc/haskell-atomic-primops/html/atomic-primops.haddock

haddock-html:         /usr/share/doc/haskell-atomic-primops/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
